==> haskell-configurator-0.3.0.0-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-JAeRHBVDh2vLq8bNyt4W0c
key: configurator-0.3.0.0-JAeRHBVDh2vLq8bNyt4W0c
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
abi: cc5cafc76f4e4d31b221d67c0dd9880b
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-JAeRHBVDh2vLq8bNyt4W0c
depends:
    attoparsec-0.13.1.0-DWdB5NAuEI54zL0UJYXwyo base-4.9.1.0
    bytestring-0.10.8.1 directory-1.3.0.0
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-5UKgHVZcPNCeuydB8f5dd
key: configurator-0.3.0.0-5UKgHVZcPNCeuydB8f5dd
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
abi: 1806bc58e566ddc0f3550b7edbbff429
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-5UKgHVZcPNCeuydB8f5dd
depends:
    attoparsec-0.13.1.0-7xLJO1EwFQpJLBzOR8WqkC base-4.9.1.0
    bytestring-0.10.8.1 directory-1.3.0.0
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    unix-compat-0.4.3.1-Ausmw6d7KIwA7sl52mzqxC
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
